# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.resource_base import ResourceBase

class Slide(ResourceBase):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'self_uri': 'ResourceUri',
        'alternate_links': 'list[ResourceUri]',
        'width': 'float',
        'height': 'float',
        'show_master_shapes': 'bool',
        'layout_slide': 'ResourceUriElement',
        'shapes': 'ResourceUriElement',
        'theme': 'ResourceUriElement',
        'placeholders': 'ResourceUriElement',
        'images': 'ResourceUriElement',
        'comments': 'ResourceUriElement',
        'background': 'ResourceUriElement',
        'notes_slide': 'ResourceUriElement'
    }

    attribute_map = {
        'self_uri': 'selfUri',
        'alternate_links': 'alternateLinks',
        'width': 'width',
        'height': 'height',
        'show_master_shapes': 'showMasterShapes',
        'layout_slide': 'layoutSlide',
        'shapes': 'shapes',
        'theme': 'theme',
        'placeholders': 'placeholders',
        'images': 'images',
        'comments': 'comments',
        'background': 'background',
        'notes_slide': 'notesSlide'
    }

    type_determiners = {
    }

    def __init__(self, self_uri=None, alternate_links=None, width=None, height=None, show_master_shapes=None, layout_slide=None, shapes=None, theme=None, placeholders=None, images=None, comments=None, background=None, notes_slide=None):  # noqa: E501
        """Slide - a model defined in Swagger"""  # noqa: E501
        super(Slide, self).__init__(self_uri, alternate_links)

        self._width = None
        self._height = None
        self._show_master_shapes = None
        self._layout_slide = None
        self._shapes = None
        self._theme = None
        self._placeholders = None
        self._images = None
        self._comments = None
        self._background = None
        self._notes_slide = None

        self.width = width
        self.height = height
        self.show_master_shapes = show_master_shapes
        if layout_slide is not None:
            self.layout_slide = layout_slide
        if shapes is not None:
            self.shapes = shapes
        if theme is not None:
            self.theme = theme
        if placeholders is not None:
            self.placeholders = placeholders
        if images is not None:
            self.images = images
        if comments is not None:
            self.comments = comments
        if background is not None:
            self.background = background
        if notes_slide is not None:
            self.notes_slide = notes_slide

    @property
    def width(self):
        """Gets the width of this Slide.  # noqa: E501

        Gets or sets the width.  # noqa: E501

        :return: The width of this Slide.  # noqa: E501
        :rtype: float
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this Slide.

        Gets or sets the width.  # noqa: E501

        :param width: The width of this Slide.  # noqa: E501
        :type: float
        """
        self._width = width

    @property
    def height(self):
        """Gets the height of this Slide.  # noqa: E501

        Gets or sets the height.  # noqa: E501

        :return: The height of this Slide.  # noqa: E501
        :rtype: float
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this Slide.

        Gets or sets the height.  # noqa: E501

        :param height: The height of this Slide.  # noqa: E501
        :type: float
        """
        self._height = height

    @property
    def show_master_shapes(self):
        """Gets the show_master_shapes of this Slide.  # noqa: E501

        Specifies if shapes of the master slide should be shown on the slide. True by default.  # noqa: E501

        :return: The show_master_shapes of this Slide.  # noqa: E501
        :rtype: bool
        """
        return self._show_master_shapes

    @show_master_shapes.setter
    def show_master_shapes(self, show_master_shapes):
        """Sets the show_master_shapes of this Slide.

        Specifies if shapes of the master slide should be shown on the slide. True by default.  # noqa: E501

        :param show_master_shapes: The show_master_shapes of this Slide.  # noqa: E501
        :type: bool
        """
        self._show_master_shapes = show_master_shapes

    @property
    def layout_slide(self):
        """Gets the layout_slide of this Slide.  # noqa: E501

        Gets or sets the  link to the layout slide.  # noqa: E501

        :return: The layout_slide of this Slide.  # noqa: E501
        :rtype: ResourceUriElement
        """
        return self._layout_slide

    @layout_slide.setter
    def layout_slide(self, layout_slide):
        """Sets the layout_slide of this Slide.

        Gets or sets the  link to the layout slide.  # noqa: E501

        :param layout_slide: The layout_slide of this Slide.  # noqa: E501
        :type: ResourceUriElement
        """
        self._layout_slide = layout_slide

    @property
    def shapes(self):
        """Gets the shapes of this Slide.  # noqa: E501

        Gets or sets the  link to list of top-level shapes.  # noqa: E501

        :return: The shapes of this Slide.  # noqa: E501
        :rtype: ResourceUriElement
        """
        return self._shapes

    @shapes.setter
    def shapes(self, shapes):
        """Sets the shapes of this Slide.

        Gets or sets the  link to list of top-level shapes.  # noqa: E501

        :param shapes: The shapes of this Slide.  # noqa: E501
        :type: ResourceUriElement
        """
        self._shapes = shapes

    @property
    def theme(self):
        """Gets the theme of this Slide.  # noqa: E501

        Gets or sets the link to theme.  # noqa: E501

        :return: The theme of this Slide.  # noqa: E501
        :rtype: ResourceUriElement
        """
        return self._theme

    @theme.setter
    def theme(self, theme):
        """Sets the theme of this Slide.

        Gets or sets the link to theme.  # noqa: E501

        :param theme: The theme of this Slide.  # noqa: E501
        :type: ResourceUriElement
        """
        self._theme = theme

    @property
    def placeholders(self):
        """Gets the placeholders of this Slide.  # noqa: E501

        Gets or sets the  link to placeholders.  # noqa: E501

        :return: The placeholders of this Slide.  # noqa: E501
        :rtype: ResourceUriElement
        """
        return self._placeholders

    @placeholders.setter
    def placeholders(self, placeholders):
        """Sets the placeholders of this Slide.

        Gets or sets the  link to placeholders.  # noqa: E501

        :param placeholders: The placeholders of this Slide.  # noqa: E501
        :type: ResourceUriElement
        """
        self._placeholders = placeholders

    @property
    def images(self):
        """Gets the images of this Slide.  # noqa: E501

        Gets or sets the link to images.  # noqa: E501

        :return: The images of this Slide.  # noqa: E501
        :rtype: ResourceUriElement
        """
        return self._images

    @images.setter
    def images(self, images):
        """Sets the images of this Slide.

        Gets or sets the link to images.  # noqa: E501

        :param images: The images of this Slide.  # noqa: E501
        :type: ResourceUriElement
        """
        self._images = images

    @property
    def comments(self):
        """Gets the comments of this Slide.  # noqa: E501

        Gets or sets the link to comments.  # noqa: E501

        :return: The comments of this Slide.  # noqa: E501
        :rtype: ResourceUriElement
        """
        return self._comments

    @comments.setter
    def comments(self, comments):
        """Sets the comments of this Slide.

        Gets or sets the link to comments.  # noqa: E501

        :param comments: The comments of this Slide.  # noqa: E501
        :type: ResourceUriElement
        """
        self._comments = comments

    @property
    def background(self):
        """Gets the background of this Slide.  # noqa: E501

        Get or sets the link to slide's background  # noqa: E501

        :return: The background of this Slide.  # noqa: E501
        :rtype: ResourceUriElement
        """
        return self._background

    @background.setter
    def background(self, background):
        """Sets the background of this Slide.

        Get or sets the link to slide's background  # noqa: E501

        :param background: The background of this Slide.  # noqa: E501
        :type: ResourceUriElement
        """
        self._background = background

    @property
    def notes_slide(self):
        """Gets the notes_slide of this Slide.  # noqa: E501

        Get or sets the link to notes slide.  # noqa: E501

        :return: The notes_slide of this Slide.  # noqa: E501
        :rtype: ResourceUriElement
        """
        return self._notes_slide

    @notes_slide.setter
    def notes_slide(self, notes_slide):
        """Sets the notes_slide of this Slide.

        Get or sets the link to notes slide.  # noqa: E501

        :param notes_slide: The notes_slide of this Slide.  # noqa: E501
        :type: ResourceUriElement
        """
        self._notes_slide = notes_slide

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Slide):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.export_options import ExportOptions

class SvgExportOptions(ExportOptions):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'format': 'str',
        'vectorize_text': 'bool',
        'metafile_rasterization_dpi': 'int',
        'disable3_d_text': 'bool',
        'disable_gradient_split': 'bool',
        'disable_line_end_cropping': 'bool',
        'jpeg_quality': 'int',
        'pictures_compression': 'str',
        'delete_pictures_cropped_areas': 'bool',
        'external_fonts_handling': 'str'
    }

    attribute_map = {
        'format': 'format',
        'vectorize_text': 'vectorizeText',
        'metafile_rasterization_dpi': 'metafileRasterizationDpi',
        'disable3_d_text': 'disable3DText',
        'disable_gradient_split': 'disableGradientSplit',
        'disable_line_end_cropping': 'disableLineEndCropping',
        'jpeg_quality': 'jpegQuality',
        'pictures_compression': 'picturesCompression',
        'delete_pictures_cropped_areas': 'deletePicturesCroppedAreas',
        'external_fonts_handling': 'externalFontsHandling'
    }

    type_determiners = {
        'format': 'svg',
    }

    def __init__(self, format='svg', vectorize_text=None, metafile_rasterization_dpi=None, disable3_d_text=None, disable_gradient_split=None, disable_line_end_cropping=None, jpeg_quality=None, pictures_compression=None, delete_pictures_cropped_areas=None, external_fonts_handling=None):  # noqa: E501
        """SvgExportOptions - a model defined in Swagger"""  # noqa: E501
        super(SvgExportOptions, self).__init__(format)

        self._vectorize_text = None
        self._metafile_rasterization_dpi = None
        self._disable3_d_text = None
        self._disable_gradient_split = None
        self._disable_line_end_cropping = None
        self._jpeg_quality = None
        self._pictures_compression = None
        self._delete_pictures_cropped_areas = None
        self._external_fonts_handling = None
        self.format: 'svg'

        self.vectorize_text = vectorize_text
        self.metafile_rasterization_dpi = metafile_rasterization_dpi
        self.disable3_d_text = disable3_d_text
        self.disable_gradient_split = disable_gradient_split
        self.disable_line_end_cropping = disable_line_end_cropping
        self.jpeg_quality = jpeg_quality
        self.pictures_compression = pictures_compression
        self.delete_pictures_cropped_areas = delete_pictures_cropped_areas
        self.external_fonts_handling = external_fonts_handling

    @property
    def vectorize_text(self):
        """Gets the vectorize_text of this SvgExportOptions.  # noqa: E501

        Determines whether the text on a slide will be saved as graphics.  # noqa: E501

        :return: The vectorize_text of this SvgExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._vectorize_text

    @vectorize_text.setter
    def vectorize_text(self, vectorize_text):
        """Sets the vectorize_text of this SvgExportOptions.

        Determines whether the text on a slide will be saved as graphics.  # noqa: E501

        :param vectorize_text: The vectorize_text of this SvgExportOptions.  # noqa: E501
        :type: bool
        """
        self._vectorize_text = vectorize_text

    @property
    def metafile_rasterization_dpi(self):
        """Gets the metafile_rasterization_dpi of this SvgExportOptions.  # noqa: E501

        Returns or sets the lower resolution limit for metafile rasterization.  # noqa: E501

        :return: The metafile_rasterization_dpi of this SvgExportOptions.  # noqa: E501
        :rtype: int
        """
        return self._metafile_rasterization_dpi

    @metafile_rasterization_dpi.setter
    def metafile_rasterization_dpi(self, metafile_rasterization_dpi):
        """Sets the metafile_rasterization_dpi of this SvgExportOptions.

        Returns or sets the lower resolution limit for metafile rasterization.  # noqa: E501

        :param metafile_rasterization_dpi: The metafile_rasterization_dpi of this SvgExportOptions.  # noqa: E501
        :type: int
        """
        self._metafile_rasterization_dpi = metafile_rasterization_dpi

    @property
    def disable3_d_text(self):
        """Gets the disable3_d_text of this SvgExportOptions.  # noqa: E501

        Determines whether the 3D text is disabled in SVG.  # noqa: E501

        :return: The disable3_d_text of this SvgExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._disable3_d_text

    @disable3_d_text.setter
    def disable3_d_text(self, disable3_d_text):
        """Sets the disable3_d_text of this SvgExportOptions.

        Determines whether the 3D text is disabled in SVG.  # noqa: E501

        :param disable3_d_text: The disable3_d_text of this SvgExportOptions.  # noqa: E501
        :type: bool
        """
        self._disable3_d_text = disable3_d_text

    @property
    def disable_gradient_split(self):
        """Gets the disable_gradient_split of this SvgExportOptions.  # noqa: E501

        Disables splitting FromCornerX and FromCenter gradients.  # noqa: E501

        :return: The disable_gradient_split of this SvgExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._disable_gradient_split

    @disable_gradient_split.setter
    def disable_gradient_split(self, disable_gradient_split):
        """Sets the disable_gradient_split of this SvgExportOptions.

        Disables splitting FromCornerX and FromCenter gradients.  # noqa: E501

        :param disable_gradient_split: The disable_gradient_split of this SvgExportOptions.  # noqa: E501
        :type: bool
        """
        self._disable_gradient_split = disable_gradient_split

    @property
    def disable_line_end_cropping(self):
        """Gets the disable_line_end_cropping of this SvgExportOptions.  # noqa: E501

        SVG 1.1 lacks ability to define insets for markers. Aspose.Slides SVG writing engine has workaround for that problem: it crops end of line with arrow, so, line doesn't overlap markers. This option switches off such behavior.  # noqa: E501

        :return: The disable_line_end_cropping of this SvgExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._disable_line_end_cropping

    @disable_line_end_cropping.setter
    def disable_line_end_cropping(self, disable_line_end_cropping):
        """Sets the disable_line_end_cropping of this SvgExportOptions.

        SVG 1.1 lacks ability to define insets for markers. Aspose.Slides SVG writing engine has workaround for that problem: it crops end of line with arrow, so, line doesn't overlap markers. This option switches off such behavior.  # noqa: E501

        :param disable_line_end_cropping: The disable_line_end_cropping of this SvgExportOptions.  # noqa: E501
        :type: bool
        """
        self._disable_line_end_cropping = disable_line_end_cropping

    @property
    def jpeg_quality(self):
        """Gets the jpeg_quality of this SvgExportOptions.  # noqa: E501

        Determines JPEG encoding quality.  # noqa: E501

        :return: The jpeg_quality of this SvgExportOptions.  # noqa: E501
        :rtype: int
        """
        return self._jpeg_quality

    @jpeg_quality.setter
    def jpeg_quality(self, jpeg_quality):
        """Sets the jpeg_quality of this SvgExportOptions.

        Determines JPEG encoding quality.  # noqa: E501

        :param jpeg_quality: The jpeg_quality of this SvgExportOptions.  # noqa: E501
        :type: int
        """
        self._jpeg_quality = jpeg_quality

    @property
    def pictures_compression(self):
        """Gets the pictures_compression of this SvgExportOptions.  # noqa: E501

        Represents the pictures compression level  # noqa: E501

        :return: The pictures_compression of this SvgExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._pictures_compression

    @pictures_compression.setter
    def pictures_compression(self, pictures_compression):
        """Sets the pictures_compression of this SvgExportOptions.

        Represents the pictures compression level  # noqa: E501

        :param pictures_compression: The pictures_compression of this SvgExportOptions.  # noqa: E501
        :type: str
        """
        if pictures_compression is not None:
            allowed_values = ["Dpi330", "Dpi220", "Dpi150", "Dpi96", "Dpi72", "DocumentResolution"]  # noqa: E501
            if pictures_compression.isdigit():
                int_pictures_compression = int(pictures_compression)
                if int_pictures_compression < 0 or int_pictures_compression >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `pictures_compression` ({0}), must be one of {1}"  # noqa: E501
                        .format(pictures_compression, allowed_values)
                    )
                self._pictures_compression = allowed_values[int_pictures_compression]
                return
            if pictures_compression not in allowed_values:
                raise ValueError(
                    "Invalid value for `pictures_compression` ({0}), must be one of {1}"  # noqa: E501
                    .format(pictures_compression, allowed_values)
                )
        self._pictures_compression = pictures_compression

    @property
    def delete_pictures_cropped_areas(self):
        """Gets the delete_pictures_cropped_areas of this SvgExportOptions.  # noqa: E501

        A boolean flag indicates if the cropped parts remain as part of the document. If true the cropped  parts will removed, if false they will be serialized in the document (which can possible lead to a  larger file)  # noqa: E501

        :return: The delete_pictures_cropped_areas of this SvgExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._delete_pictures_cropped_areas

    @delete_pictures_cropped_areas.setter
    def delete_pictures_cropped_areas(self, delete_pictures_cropped_areas):
        """Sets the delete_pictures_cropped_areas of this SvgExportOptions.

        A boolean flag indicates if the cropped parts remain as part of the document. If true the cropped  parts will removed, if false they will be serialized in the document (which can possible lead to a  larger file)  # noqa: E501

        :param delete_pictures_cropped_areas: The delete_pictures_cropped_areas of this SvgExportOptions.  # noqa: E501
        :type: bool
        """
        self._delete_pictures_cropped_areas = delete_pictures_cropped_areas

    @property
    def external_fonts_handling(self):
        """Gets the external_fonts_handling of this SvgExportOptions.  # noqa: E501

        Determines a way of handling externally loaded fonts.  # noqa: E501

        :return: The external_fonts_handling of this SvgExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._external_fonts_handling

    @external_fonts_handling.setter
    def external_fonts_handling(self, external_fonts_handling):
        """Sets the external_fonts_handling of this SvgExportOptions.

        Determines a way of handling externally loaded fonts.  # noqa: E501

        :param external_fonts_handling: The external_fonts_handling of this SvgExportOptions.  # noqa: E501
        :type: str
        """
        if external_fonts_handling is not None:
            allowed_values = ["AddLinksToFontFiles", "Embed", "Vectorize"]  # noqa: E501
            if external_fonts_handling.isdigit():
                int_external_fonts_handling = int(external_fonts_handling)
                if int_external_fonts_handling < 0 or int_external_fonts_handling >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `external_fonts_handling` ({0}), must be one of {1}"  # noqa: E501
                        .format(external_fonts_handling, allowed_values)
                    )
                self._external_fonts_handling = allowed_values[int_external_fonts_handling]
                return
            if external_fonts_handling not in allowed_values:
                raise ValueError(
                    "Invalid value for `external_fonts_handling` ({0}), must be one of {1}"  # noqa: E501
                    .format(external_fonts_handling, allowed_values)
                )
        self._external_fonts_handling = external_fonts_handling

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SvgExportOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.export_options import ExportOptions

class SwfExportOptions(ExportOptions):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'format': 'str',
        'show_hidden_slides': 'bool',
        'compressed': 'bool',
        'viewer_included': 'bool',
        'show_page_border': 'bool',
        'show_full_screen': 'bool',
        'show_page_stepper': 'bool',
        'show_search': 'bool',
        'show_top_pane': 'bool',
        'show_bottom_pane': 'bool',
        'show_left_pane': 'bool',
        'start_open_left_pane': 'bool',
        'enable_context_menu': 'bool',
        'logo_image': 'str',
        'logo_link': 'str',
        'jpeg_quality': 'int',
        'notes_position': 'str',
        'comments_position': 'str',
        'comments_area_width': 'int',
        'comments_area_color': 'str',
        'show_comments_by_no_author': 'bool'
    }

    attribute_map = {
        'format': 'format',
        'show_hidden_slides': 'showHiddenSlides',
        'compressed': 'compressed',
        'viewer_included': 'viewerIncluded',
        'show_page_border': 'showPageBorder',
        'show_full_screen': 'showFullScreen',
        'show_page_stepper': 'showPageStepper',
        'show_search': 'showSearch',
        'show_top_pane': 'showTopPane',
        'show_bottom_pane': 'showBottomPane',
        'show_left_pane': 'showLeftPane',
        'start_open_left_pane': 'startOpenLeftPane',
        'enable_context_menu': 'enableContextMenu',
        'logo_image': 'logoImage',
        'logo_link': 'logoLink',
        'jpeg_quality': 'jpegQuality',
        'notes_position': 'notesPosition',
        'comments_position': 'commentsPosition',
        'comments_area_width': 'commentsAreaWidth',
        'comments_area_color': 'commentsAreaColor',
        'show_comments_by_no_author': 'showCommentsByNoAuthor'
    }

    type_determiners = {
        'format': 'swf',
    }

    def __init__(self, format='swf', show_hidden_slides=None, compressed=None, viewer_included=None, show_page_border=None, show_full_screen=None, show_page_stepper=None, show_search=None, show_top_pane=None, show_bottom_pane=None, show_left_pane=None, start_open_left_pane=None, enable_context_menu=None, logo_image=None, logo_link=None, jpeg_quality=None, notes_position=None, comments_position=None, comments_area_width=None, comments_area_color=None, show_comments_by_no_author=None):  # noqa: E501
        """SwfExportOptions - a model defined in Swagger"""  # noqa: E501
        super(SwfExportOptions, self).__init__(format)

        self._show_hidden_slides = None
        self._compressed = None
        self._viewer_included = None
        self._show_page_border = None
        self._show_full_screen = None
        self._show_page_stepper = None
        self._show_search = None
        self._show_top_pane = None
        self._show_bottom_pane = None
        self._show_left_pane = None
        self._start_open_left_pane = None
        self._enable_context_menu = None
        self._logo_image = None
        self._logo_link = None
        self._jpeg_quality = None
        self._notes_position = None
        self._comments_position = None
        self._comments_area_width = None
        self._comments_area_color = None
        self._show_comments_by_no_author = None
        self.format: 'swf'

        self.show_hidden_slides = show_hidden_slides
        self.compressed = compressed
        self.viewer_included = viewer_included
        self.show_page_border = show_page_border
        self.show_full_screen = show_full_screen
        self.show_page_stepper = show_page_stepper
        self.show_search = show_search
        self.show_top_pane = show_top_pane
        self.show_bottom_pane = show_bottom_pane
        self.show_left_pane = show_left_pane
        self.start_open_left_pane = start_open_left_pane
        self.enable_context_menu = enable_context_menu
        if logo_image is not None:
            self.logo_image = logo_image
        if logo_link is not None:
            self.logo_link = logo_link
        self.jpeg_quality = jpeg_quality
        self.notes_position = notes_position
        self.comments_position = comments_position
        self.comments_area_width = comments_area_width
        if comments_area_color is not None:
            self.comments_area_color = comments_area_color
        self.show_comments_by_no_author = show_comments_by_no_author

    @property
    def show_hidden_slides(self):
        """Gets the show_hidden_slides of this SwfExportOptions.  # noqa: E501

        Specifies whether the generated document should include hidden slides or not. Default is false.   # noqa: E501

        :return: The show_hidden_slides of this SwfExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._show_hidden_slides

    @show_hidden_slides.setter
    def show_hidden_slides(self, show_hidden_slides):
        """Sets the show_hidden_slides of this SwfExportOptions.

        Specifies whether the generated document should include hidden slides or not. Default is false.   # noqa: E501

        :param show_hidden_slides: The show_hidden_slides of this SwfExportOptions.  # noqa: E501
        :type: bool
        """
        self._show_hidden_slides = show_hidden_slides

    @property
    def compressed(self):
        """Gets the compressed of this SwfExportOptions.  # noqa: E501

        Specifies whether the generated SWF document should be compressed or not. Default is true.   # noqa: E501

        :return: The compressed of this SwfExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._compressed

    @compressed.setter
    def compressed(self, compressed):
        """Sets the compressed of this SwfExportOptions.

        Specifies whether the generated SWF document should be compressed or not. Default is true.   # noqa: E501

        :param compressed: The compressed of this SwfExportOptions.  # noqa: E501
        :type: bool
        """
        self._compressed = compressed

    @property
    def viewer_included(self):
        """Gets the viewer_included of this SwfExportOptions.  # noqa: E501

        Specifies whether the generated SWF document should include the integrated document viewer or not. Default is true.   # noqa: E501

        :return: The viewer_included of this SwfExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._viewer_included

    @viewer_included.setter
    def viewer_included(self, viewer_included):
        """Sets the viewer_included of this SwfExportOptions.

        Specifies whether the generated SWF document should include the integrated document viewer or not. Default is true.   # noqa: E501

        :param viewer_included: The viewer_included of this SwfExportOptions.  # noqa: E501
        :type: bool
        """
        self._viewer_included = viewer_included

    @property
    def show_page_border(self):
        """Gets the show_page_border of this SwfExportOptions.  # noqa: E501

        Specifies whether border around pages should be shown. Default is true.   # noqa: E501

        :return: The show_page_border of this SwfExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._show_page_border

    @show_page_border.setter
    def show_page_border(self, show_page_border):
        """Sets the show_page_border of this SwfExportOptions.

        Specifies whether border around pages should be shown. Default is true.   # noqa: E501

        :param show_page_border: The show_page_border of this SwfExportOptions.  # noqa: E501
        :type: bool
        """
        self._show_page_border = show_page_border

    @property
    def show_full_screen(self):
        """Gets the show_full_screen of this SwfExportOptions.  # noqa: E501

        Show/hide fullscreen button. Can be overridden in flashvars. Default is true.   # noqa: E501

        :return: The show_full_screen of this SwfExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._show_full_screen

    @show_full_screen.setter
    def show_full_screen(self, show_full_screen):
        """Sets the show_full_screen of this SwfExportOptions.

        Show/hide fullscreen button. Can be overridden in flashvars. Default is true.   # noqa: E501

        :param show_full_screen: The show_full_screen of this SwfExportOptions.  # noqa: E501
        :type: bool
        """
        self._show_full_screen = show_full_screen

    @property
    def show_page_stepper(self):
        """Gets the show_page_stepper of this SwfExportOptions.  # noqa: E501

        Show/hide page stepper. Can be overridden in flashvars. Default is true.   # noqa: E501

        :return: The show_page_stepper of this SwfExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._show_page_stepper

    @show_page_stepper.setter
    def show_page_stepper(self, show_page_stepper):
        """Sets the show_page_stepper of this SwfExportOptions.

        Show/hide page stepper. Can be overridden in flashvars. Default is true.   # noqa: E501

        :param show_page_stepper: The show_page_stepper of this SwfExportOptions.  # noqa: E501
        :type: bool
        """
        self._show_page_stepper = show_page_stepper

    @property
    def show_search(self):
        """Gets the show_search of this SwfExportOptions.  # noqa: E501

        Show/hide search section. Can be overridden in flashvars. Default is true.   # noqa: E501

        :return: The show_search of this SwfExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._show_search

    @show_search.setter
    def show_search(self, show_search):
        """Sets the show_search of this SwfExportOptions.

        Show/hide search section. Can be overridden in flashvars. Default is true.   # noqa: E501

        :param show_search: The show_search of this SwfExportOptions.  # noqa: E501
        :type: bool
        """
        self._show_search = show_search

    @property
    def show_top_pane(self):
        """Gets the show_top_pane of this SwfExportOptions.  # noqa: E501

        Show/hide whole top pane. Can be overridden in flashvars. Default is true.   # noqa: E501

        :return: The show_top_pane of this SwfExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._show_top_pane

    @show_top_pane.setter
    def show_top_pane(self, show_top_pane):
        """Sets the show_top_pane of this SwfExportOptions.

        Show/hide whole top pane. Can be overridden in flashvars. Default is true.   # noqa: E501

        :param show_top_pane: The show_top_pane of this SwfExportOptions.  # noqa: E501
        :type: bool
        """
        self._show_top_pane = show_top_pane

    @property
    def show_bottom_pane(self):
        """Gets the show_bottom_pane of this SwfExportOptions.  # noqa: E501

        Show/hide bottom pane. Can be overridden in flashvars. Default is true.   # noqa: E501

        :return: The show_bottom_pane of this SwfExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._show_bottom_pane

    @show_bottom_pane.setter
    def show_bottom_pane(self, show_bottom_pane):
        """Sets the show_bottom_pane of this SwfExportOptions.

        Show/hide bottom pane. Can be overridden in flashvars. Default is true.   # noqa: E501

        :param show_bottom_pane: The show_bottom_pane of this SwfExportOptions.  # noqa: E501
        :type: bool
        """
        self._show_bottom_pane = show_bottom_pane

    @property
    def show_left_pane(self):
        """Gets the show_left_pane of this SwfExportOptions.  # noqa: E501

        Show/hide left pane. Can be overridden in flashvars. Default is true.   # noqa: E501

        :return: The show_left_pane of this SwfExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._show_left_pane

    @show_left_pane.setter
    def show_left_pane(self, show_left_pane):
        """Sets the show_left_pane of this SwfExportOptions.

        Show/hide left pane. Can be overridden in flashvars. Default is true.   # noqa: E501

        :param show_left_pane: The show_left_pane of this SwfExportOptions.  # noqa: E501
        :type: bool
        """
        self._show_left_pane = show_left_pane

    @property
    def start_open_left_pane(self):
        """Gets the start_open_left_pane of this SwfExportOptions.  # noqa: E501

        Start with opened left pane. Can be overridden in flashvars. Default is false.   # noqa: E501

        :return: The start_open_left_pane of this SwfExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._start_open_left_pane

    @start_open_left_pane.setter
    def start_open_left_pane(self, start_open_left_pane):
        """Sets the start_open_left_pane of this SwfExportOptions.

        Start with opened left pane. Can be overridden in flashvars. Default is false.   # noqa: E501

        :param start_open_left_pane: The start_open_left_pane of this SwfExportOptions.  # noqa: E501
        :type: bool
        """
        self._start_open_left_pane = start_open_left_pane

    @property
    def enable_context_menu(self):
        """Gets the enable_context_menu of this SwfExportOptions.  # noqa: E501

        Enable/disable context menu. Default is true.   # noqa: E501

        :return: The enable_context_menu of this SwfExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._enable_context_menu

    @enable_context_menu.setter
    def enable_context_menu(self, enable_context_menu):
        """Sets the enable_context_menu of this SwfExportOptions.

        Enable/disable context menu. Default is true.   # noqa: E501

        :param enable_context_menu: The enable_context_menu of this SwfExportOptions.  # noqa: E501
        :type: bool
        """
        self._enable_context_menu = enable_context_menu

    @property
    def logo_image(self):
        """Gets the logo_image of this SwfExportOptions.  # noqa: E501

        Image that will be displayed as logo in the top right corner of the viewer. The image data is a base 64 string. Image should be 32x64 pixels PNG image, otherwise logo can be displayed improperly.   # noqa: E501

        :return: The logo_image of this SwfExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._logo_image

    @logo_image.setter
    def logo_image(self, logo_image):
        """Sets the logo_image of this SwfExportOptions.

        Image that will be displayed as logo in the top right corner of the viewer. The image data is a base 64 string. Image should be 32x64 pixels PNG image, otherwise logo can be displayed improperly.   # noqa: E501

        :param logo_image: The logo_image of this SwfExportOptions.  # noqa: E501
        :type: str
        """
        self._logo_image = logo_image

    @property
    def logo_link(self):
        """Gets the logo_link of this SwfExportOptions.  # noqa: E501

        Gets or sets the full hyperlink address for a logo. Has an effect only if a LogoImage is specified.   # noqa: E501

        :return: The logo_link of this SwfExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._logo_link

    @logo_link.setter
    def logo_link(self, logo_link):
        """Sets the logo_link of this SwfExportOptions.

        Gets or sets the full hyperlink address for a logo. Has an effect only if a LogoImage is specified.   # noqa: E501

        :param logo_link: The logo_link of this SwfExportOptions.  # noqa: E501
        :type: str
        """
        self._logo_link = logo_link

    @property
    def jpeg_quality(self):
        """Gets the jpeg_quality of this SwfExportOptions.  # noqa: E501

        Specifies the quality of JPEG images. Default is 95.  # noqa: E501

        :return: The jpeg_quality of this SwfExportOptions.  # noqa: E501
        :rtype: int
        """
        return self._jpeg_quality

    @jpeg_quality.setter
    def jpeg_quality(self, jpeg_quality):
        """Sets the jpeg_quality of this SwfExportOptions.

        Specifies the quality of JPEG images. Default is 95.  # noqa: E501

        :param jpeg_quality: The jpeg_quality of this SwfExportOptions.  # noqa: E501
        :type: int
        """
        self._jpeg_quality = jpeg_quality

    @property
    def notes_position(self):
        """Gets the notes_position of this SwfExportOptions.  # noqa: E501

        Gets or sets the position of the notes on the page.  # noqa: E501

        :return: The notes_position of this SwfExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._notes_position

    @notes_position.setter
    def notes_position(self, notes_position):
        """Sets the notes_position of this SwfExportOptions.

        Gets or sets the position of the notes on the page.  # noqa: E501

        :param notes_position: The notes_position of this SwfExportOptions.  # noqa: E501
        :type: str
        """
        if notes_position is not None:
            allowed_values = ["None", "BottomFull", "BottomTruncated"]  # noqa: E501
            if notes_position.isdigit():
                int_notes_position = int(notes_position)
                if int_notes_position < 0 or int_notes_position >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `notes_position` ({0}), must be one of {1}"  # noqa: E501
                        .format(notes_position, allowed_values)
                    )
                self._notes_position = allowed_values[int_notes_position]
                return
            if notes_position not in allowed_values:
                raise ValueError(
                    "Invalid value for `notes_position` ({0}), must be one of {1}"  # noqa: E501
                    .format(notes_position, allowed_values)
                )
        self._notes_position = notes_position

    @property
    def comments_position(self):
        """Gets the comments_position of this SwfExportOptions.  # noqa: E501

        Gets or sets the position of the comments on the page.  # noqa: E501

        :return: The comments_position of this SwfExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._comments_position

    @comments_position.setter
    def comments_position(self, comments_position):
        """Sets the comments_position of this SwfExportOptions.

        Gets or sets the position of the comments on the page.  # noqa: E501

        :param comments_position: The comments_position of this SwfExportOptions.  # noqa: E501
        :type: str
        """
        if comments_position is not None:
            allowed_values = ["None", "Bottom", "Right"]  # noqa: E501
            if comments_position.isdigit():
                int_comments_position = int(comments_position)
                if int_comments_position < 0 or int_comments_position >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `comments_position` ({0}), must be one of {1}"  # noqa: E501
                        .format(comments_position, allowed_values)
                    )
                self._comments_position = allowed_values[int_comments_position]
                return
            if comments_position not in allowed_values:
                raise ValueError(
                    "Invalid value for `comments_position` ({0}), must be one of {1}"  # noqa: E501
                    .format(comments_position, allowed_values)
                )
        self._comments_position = comments_position

    @property
    def comments_area_width(self):
        """Gets the comments_area_width of this SwfExportOptions.  # noqa: E501

        Gets or sets the width of the comment output area in pixels (Applies only if comments are displayed on the right).  # noqa: E501

        :return: The comments_area_width of this SwfExportOptions.  # noqa: E501
        :rtype: int
        """
        return self._comments_area_width

    @comments_area_width.setter
    def comments_area_width(self, comments_area_width):
        """Sets the comments_area_width of this SwfExportOptions.

        Gets or sets the width of the comment output area in pixels (Applies only if comments are displayed on the right).  # noqa: E501

        :param comments_area_width: The comments_area_width of this SwfExportOptions.  # noqa: E501
        :type: int
        """
        self._comments_area_width = comments_area_width

    @property
    def comments_area_color(self):
        """Gets the comments_area_color of this SwfExportOptions.  # noqa: E501

        Gets or sets the color of comments area (Applies only if comments are displayed on the right).  # noqa: E501

        :return: The comments_area_color of this SwfExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._comments_area_color

    @comments_area_color.setter
    def comments_area_color(self, comments_area_color):
        """Sets the comments_area_color of this SwfExportOptions.

        Gets or sets the color of comments area (Applies only if comments are displayed on the right).  # noqa: E501

        :param comments_area_color: The comments_area_color of this SwfExportOptions.  # noqa: E501
        :type: str
        """
        self._comments_area_color = comments_area_color

    @property
    def show_comments_by_no_author(self):
        """Gets the show_comments_by_no_author of this SwfExportOptions.  # noqa: E501

        True if comments that have no author are displayed. (Applies only if comments are displayed).  # noqa: E501

        :return: The show_comments_by_no_author of this SwfExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._show_comments_by_no_author

    @show_comments_by_no_author.setter
    def show_comments_by_no_author(self, show_comments_by_no_author):
        """Sets the show_comments_by_no_author of this SwfExportOptions.

        True if comments that have no author are displayed. (Applies only if comments are displayed).  # noqa: E501

        :param show_comments_by_no_author: The show_comments_by_no_author of this SwfExportOptions.  # noqa: E501
        :type: bool
        """
        self._show_comments_by_no_author = show_comments_by_no_author

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SwfExportOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

from __future__ import absolute_import

# import models into model package
from asposeslidescloud.models.api_info import ApiInfo
from asposeslidescloud.models.arrow_head_properties import ArrowHeadProperties
from asposeslidescloud.models.axes import Axes
from asposeslidescloud.models.axis import Axis
from asposeslidescloud.models.blur_effect import BlurEffect
from asposeslidescloud.models.chart_category import ChartCategory
from asposeslidescloud.models.chart_title import ChartTitle
from asposeslidescloud.models.chart_wall import ChartWall
from asposeslidescloud.models.common_slide_view_properties import CommonSlideViewProperties
from asposeslidescloud.models.custom_dash_pattern import CustomDashPattern
from asposeslidescloud.models.disc_usage import DiscUsage
from asposeslidescloud.models.effect import Effect
from asposeslidescloud.models.effect_format import EffectFormat
from asposeslidescloud.models.error import Error
from asposeslidescloud.models.error_details import ErrorDetails
from asposeslidescloud.models.export_format import ExportFormat
from asposeslidescloud.models.export_options import ExportOptions
from asposeslidescloud.models.file_versions import FileVersions
from asposeslidescloud.models.files_list import FilesList
from asposeslidescloud.models.files_upload_result import FilesUploadResult
from asposeslidescloud.models.fill_format import FillFormat
from asposeslidescloud.models.fill_overlay_effect import FillOverlayEffect
from asposeslidescloud.models.font_set import FontSet
from asposeslidescloud.models.glow_effect import GlowEffect
from asposeslidescloud.models.gradient_fill_stop import GradientFillStop
from asposeslidescloud.models.i_shape_export_options import IShapeExportOptions
from asposeslidescloud.models.image_export_format import ImageExportFormat
from asposeslidescloud.models.inner_shadow_effect import InnerShadowEffect
from asposeslidescloud.models.input import Input
from asposeslidescloud.models.input_file import InputFile
from asposeslidescloud.models.interactive_sequence import InteractiveSequence
from asposeslidescloud.models.legend import Legend
from asposeslidescloud.models.line_format import LineFormat
from asposeslidescloud.models.merging_source import MergingSource
from asposeslidescloud.models.normal_view_restored_properties import NormalViewRestoredProperties
from asposeslidescloud.models.notes_slide_export_format import NotesSlideExportFormat
from asposeslidescloud.models.object_exist import ObjectExist
from asposeslidescloud.models.one_value_chart_data_point import OneValueChartDataPoint
from asposeslidescloud.models.ordered_merge_request import OrderedMergeRequest
from asposeslidescloud.models.outer_shadow_effect import OuterShadowEffect
from asposeslidescloud.models.output_file import OutputFile
from asposeslidescloud.models.pipeline import Pipeline
from asposeslidescloud.models.plot_area import PlotArea
from asposeslidescloud.models.presentation_to_merge import PresentationToMerge
from asposeslidescloud.models.presentations_merge_request import PresentationsMergeRequest
from asposeslidescloud.models.preset_shadow_effect import PresetShadowEffect
from asposeslidescloud.models.reflection_effect import ReflectionEffect
from asposeslidescloud.models.resource_base import ResourceBase
from asposeslidescloud.models.resource_uri import ResourceUri
from asposeslidescloud.models.resource_uri_element import ResourceUriElement
from asposeslidescloud.models.scale_type import ScaleType
from asposeslidescloud.models.scatter_chart_data_point import ScatterChartDataPoint
from asposeslidescloud.models.series import Series
from asposeslidescloud.models.series_marker import SeriesMarker
from asposeslidescloud.models.shape_export_format import ShapeExportFormat
from asposeslidescloud.models.shape_image_export_options import ShapeImageExportOptions
from asposeslidescloud.models.shape_thumbnail_bounds import ShapeThumbnailBounds
from asposeslidescloud.models.size_type import SizeType
from asposeslidescloud.models.slide_comment import SlideComment
from asposeslidescloud.models.slide_export_format import SlideExportFormat
from asposeslidescloud.models.smart_art_node import SmartArtNode
from asposeslidescloud.models.soft_edge_effect import SoftEdgeEffect
from asposeslidescloud.models.storage_exist import StorageExist
from asposeslidescloud.models.storage_file import StorageFile
from asposeslidescloud.models.table_cell import TableCell
from asposeslidescloud.models.table_column import TableColumn
from asposeslidescloud.models.table_row import TableRow
from asposeslidescloud.models.task import Task
from asposeslidescloud.models.text_item import TextItem
from asposeslidescloud.models.add_layout_slide import AddLayoutSlide
from asposeslidescloud.models.add_master_slide import AddMasterSlide
from asposeslidescloud.models.add_shape import AddShape
from asposeslidescloud.models.add_slide import AddSlide
from asposeslidescloud.models.base64_input_file import Base64InputFile
from asposeslidescloud.models.bubble_chart_data_point import BubbleChartDataPoint
from asposeslidescloud.models.bubble_series import BubbleSeries
from asposeslidescloud.models.color_scheme import ColorScheme
from asposeslidescloud.models.document import Document
from asposeslidescloud.models.document_properties import DocumentProperties
from asposeslidescloud.models.document_property import DocumentProperty
from asposeslidescloud.models.file_version import FileVersion
from asposeslidescloud.models.font_scheme import FontScheme
from asposeslidescloud.models.format_scheme import FormatScheme
from asposeslidescloud.models.gradient_fill import GradientFill
from asposeslidescloud.models.html_export_options import HtmlExportOptions
from asposeslidescloud.models.image import Image
from asposeslidescloud.models.image_export_options import ImageExportOptions
from asposeslidescloud.models.images import Images
from asposeslidescloud.models.layout_slide import LayoutSlide
from asposeslidescloud.models.layout_slides import LayoutSlides
from asposeslidescloud.models.master_slide import MasterSlide
from asposeslidescloud.models.master_slides import MasterSlides
from asposeslidescloud.models.merge import Merge
from asposeslidescloud.models.no_fill import NoFill
from asposeslidescloud.models.notes_slide import NotesSlide
from asposeslidescloud.models.one_value_series import OneValueSeries
from asposeslidescloud.models.paragraph import Paragraph
from asposeslidescloud.models.paragraphs import Paragraphs
from asposeslidescloud.models.path_input_file import PathInputFile
from asposeslidescloud.models.path_output_file import PathOutputFile
from asposeslidescloud.models.pattern_fill import PatternFill
from asposeslidescloud.models.pdf_export_options import PdfExportOptions
from asposeslidescloud.models.picture_fill import PictureFill
from asposeslidescloud.models.placeholder import Placeholder
from asposeslidescloud.models.placeholders import Placeholders
from asposeslidescloud.models.portion import Portion
from asposeslidescloud.models.portions import Portions
from asposeslidescloud.models.pptx_export_options import PptxExportOptions
from asposeslidescloud.models.remove_shape import RemoveShape
from asposeslidescloud.models.remove_slide import RemoveSlide
from asposeslidescloud.models.reorder_slide import ReorderSlide
from asposeslidescloud.models.replace_text import ReplaceText
from asposeslidescloud.models.request_input_file import RequestInputFile
from asposeslidescloud.models.reset_slide import ResetSlide
from asposeslidescloud.models.response_output_file import ResponseOutputFile
from asposeslidescloud.models.save import Save
from asposeslidescloud.models.save_shape import SaveShape
from asposeslidescloud.models.save_slide import SaveSlide
from asposeslidescloud.models.scatter_series import ScatterSeries
from asposeslidescloud.models.shape_base import ShapeBase
from asposeslidescloud.models.shapes import Shapes
from asposeslidescloud.models.slide import Slide
from asposeslidescloud.models.slide_animation import SlideAnimation
from asposeslidescloud.models.slide_background import SlideBackground
from asposeslidescloud.models.slide_comments import SlideComments
from asposeslidescloud.models.slides import Slides
from asposeslidescloud.models.solid_fill import SolidFill
from asposeslidescloud.models.split_document_result import SplitDocumentResult
from asposeslidescloud.models.svg_export_options import SvgExportOptions
from asposeslidescloud.models.swf_export_options import SwfExportOptions
from asposeslidescloud.models.text_items import TextItems
from asposeslidescloud.models.theme import Theme
from asposeslidescloud.models.tiff_export_options import TiffExportOptions
from asposeslidescloud.models.update_background import UpdateBackground
from asposeslidescloud.models.update_shape import UpdateShape
from asposeslidescloud.models.view_properties import ViewProperties
from asposeslidescloud.models.xps_export_options import XpsExportOptions
from asposeslidescloud.models.box_and_whisker_series import BoxAndWhiskerSeries
from asposeslidescloud.models.chart import Chart
from asposeslidescloud.models.document_replace_result import DocumentReplaceResult
from asposeslidescloud.models.geometry_shape import GeometryShape
from asposeslidescloud.models.graphical_object import GraphicalObject
from asposeslidescloud.models.group_shape import GroupShape
from asposeslidescloud.models.ole_object_frame import OleObjectFrame
from asposeslidescloud.models.slide_replace_result import SlideReplaceResult
from asposeslidescloud.models.smart_art import SmartArt
from asposeslidescloud.models.smart_art_shape import SmartArtShape
from asposeslidescloud.models.table import Table
from asposeslidescloud.models.waterfall_series import WaterfallSeries
from asposeslidescloud.models.audio_frame import AudioFrame
from asposeslidescloud.models.connector import Connector
from asposeslidescloud.models.picture_frame import PictureFrame
from asposeslidescloud.models.shape import Shape
from asposeslidescloud.models.video_frame import VideoFrame


from asposeslidescloud.models.requests.slides_api_requests import CopyFileRequest
from asposeslidescloud.models.requests.slides_api_requests import CopyFolderRequest
from asposeslidescloud.models.requests.slides_api_requests import CreateFolderRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteFileRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteFolderRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteNotesSlideRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteNotesSlideParagraphRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteNotesSlideParagraphsRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteNotesSlidePortionRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteNotesSlidePortionsRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteNotesSlideShapeRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteNotesSlideShapesRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteParagraphRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteParagraphsRequest
from asposeslidescloud.models.requests.slides_api_requests import DeletePortionRequest
from asposeslidescloud.models.requests.slides_api_requests import DeletePortionsRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideAnimationRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideAnimationEffectRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideAnimationInteractiveSequenceRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideAnimationInteractiveSequenceEffectRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideAnimationInteractiveSequencesRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideAnimationMainSequenceRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideByIndexRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideShapeRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideShapesRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlidesCleanSlidesListRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlidesDocumentPropertiesRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlidesDocumentPropertyRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlidesSlideBackgroundRequest
from asposeslidescloud.models.requests.slides_api_requests import DownloadFileRequest
from asposeslidescloud.models.requests.slides_api_requests import GetDiscUsageRequest
from asposeslidescloud.models.requests.slides_api_requests import GetFileVersionsRequest
from asposeslidescloud.models.requests.slides_api_requests import GetFilesListRequest
from asposeslidescloud.models.requests.slides_api_requests import GetLayoutSlideRequest
from asposeslidescloud.models.requests.slides_api_requests import GetLayoutSlidesListRequest
from asposeslidescloud.models.requests.slides_api_requests import GetMasterSlideRequest
from asposeslidescloud.models.requests.slides_api_requests import GetMasterSlidesListRequest
from asposeslidescloud.models.requests.slides_api_requests import GetNotesSlideRequest
from asposeslidescloud.models.requests.slides_api_requests import GetNotesSlideShapeRequest
from asposeslidescloud.models.requests.slides_api_requests import GetNotesSlideShapeParagraphRequest
from asposeslidescloud.models.requests.slides_api_requests import GetNotesSlideShapeParagraphsRequest
from asposeslidescloud.models.requests.slides_api_requests import GetNotesSlideShapePortionRequest
from asposeslidescloud.models.requests.slides_api_requests import GetNotesSlideShapePortionsRequest
from asposeslidescloud.models.requests.slides_api_requests import GetNotesSlideShapesRequest
from asposeslidescloud.models.requests.slides_api_requests import GetNotesSlideWithFormatRequest
from asposeslidescloud.models.requests.slides_api_requests import GetParagraphPortionRequest
from asposeslidescloud.models.requests.slides_api_requests import GetParagraphPortionsRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlideAnimationRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlideShapeRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlideShapeParagraphRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlideShapeParagraphsRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlideShapesRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesDocumentRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesDocumentPropertiesRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesDocumentPropertyRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesImageWithDefaultFormatRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesImageWithFormatRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesImagesRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesPlaceholderRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesPlaceholdersRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesPresentationTextItemsRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesSlideRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesSlideBackgroundRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesSlideCommentsRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesSlideImagesRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesSlideTextItemsRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesSlidesListRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesThemeRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesThemeColorSchemeRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesThemeFontSchemeRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesThemeFormatSchemeRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesViewPropertiesRequest
from asposeslidescloud.models.requests.slides_api_requests import MoveFileRequest
from asposeslidescloud.models.requests.slides_api_requests import MoveFolderRequest
from asposeslidescloud.models.requests.slides_api_requests import ObjectExistsRequest
from asposeslidescloud.models.requests.slides_api_requests import PostAddNewParagraphRequest
from asposeslidescloud.models.requests.slides_api_requests import PostAddNewPortionRequest
from asposeslidescloud.models.requests.slides_api_requests import PostAddNewShapeRequest
from asposeslidescloud.models.requests.slides_api_requests import PostAddNotesSlideRequest
from asposeslidescloud.models.requests.slides_api_requests import PostCopyLayoutSlideFromSourcePresentationRequest
from asposeslidescloud.models.requests.slides_api_requests import PostCopyMasterSlideFromSourcePresentationRequest
from asposeslidescloud.models.requests.slides_api_requests import PostNotesSlideAddNewParagraphRequest
from asposeslidescloud.models.requests.slides_api_requests import PostNotesSlideAddNewPortionRequest
from asposeslidescloud.models.requests.slides_api_requests import PostNotesSlideAddNewShapeRequest
from asposeslidescloud.models.requests.slides_api_requests import PostNotesSlideShapeSaveAsRequest
from asposeslidescloud.models.requests.slides_api_requests import PostPresentationMergeRequest
from asposeslidescloud.models.requests.slides_api_requests import PostShapeSaveAsRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlideAnimationEffectRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlideAnimationInteractiveSequenceRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlideAnimationInteractiveSequenceEffectRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlideSaveAsRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesAddRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesConvertRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesCopyRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesDocumentRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesDocumentFromHtmlRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesDocumentFromSourceRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesDocumentFromTemplateRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesPipelineRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesPresentationReplaceTextRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesReorderRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesReorderManyRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesSaveAsRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesSetDocumentPropertiesRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesSlideReplaceTextRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesSplitRequest
from asposeslidescloud.models.requests.slides_api_requests import PutLayoutSlideRequest
from asposeslidescloud.models.requests.slides_api_requests import PutNotesSlideShapeSaveAsRequest
from asposeslidescloud.models.requests.slides_api_requests import PutPresentationMergeRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSetParagraphPortionPropertiesRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSetParagraphPropertiesRequest
from asposeslidescloud.models.requests.slides_api_requests import PutShapeSaveAsRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlideAnimationRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlideAnimationEffectRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlideAnimationInteractiveSequenceEffectRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlideSaveAsRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlideShapeInfoRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlidesConvertRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlidesDocumentFromHtmlRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlidesSaveAsRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlidesSetDocumentPropertyRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlidesSlideRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlidesSlideBackgroundRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlidesSlideBackgroundColorRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlidesSlideSizeRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlidesViewPropertiesRequest
from asposeslidescloud.models.requests.slides_api_requests import PutUpdateNotesSlideRequest
from asposeslidescloud.models.requests.slides_api_requests import PutUpdateNotesSlideShapeRequest
from asposeslidescloud.models.requests.slides_api_requests import PutUpdateNotesSlideShapeParagraphRequest
from asposeslidescloud.models.requests.slides_api_requests import PutUpdateNotesSlideShapePortionRequest
from asposeslidescloud.models.requests.slides_api_requests import StorageExistsRequest
from asposeslidescloud.models.requests.slides_api_requests import UploadFileRequest



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six


class Axis(object):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_visible': 'bool',
        'has_title': 'bool',
        'position': 'str',
        'display_unit': 'str',
        'base_unit_scale': 'str',
        'is_automatic_major_unit': 'bool',
        'major_unit': 'float',
        'major_unit_scale': 'str',
        'major_tick_mark': 'str',
        'is_automatic_minor_unit': 'bool',
        'minor_unit': 'float',
        'minor_unit_scale': 'str',
        'minor_tick_mark': 'str',
        'is_automatic_max_value': 'bool',
        'max_value': 'float',
        'is_automatic_min_value': 'bool',
        'min_value': 'float',
        'is_logarithmic': 'bool',
        'log_base': 'float',
        'category_axis_type': 'str',
        'axis_between_categories': 'bool',
        'label_offset': 'int',
        'is_plot_order_reversed': 'bool',
        'is_number_format_linked_to_source': 'bool',
        'number_format': 'str',
        'cross_type': 'str',
        'cross_at': 'float',
        'is_automatic_tick_marks_spacing': 'bool',
        'tick_marks_spacing': 'int',
        'is_automatic_tick_label_spacing': 'bool',
        'tick_label_spacing': 'int',
        'tick_label_position': 'str',
        'tick_label_rotation_angle': 'float',
        'fill_format': 'FillFormat',
        'effect_format': 'EffectFormat',
        'line_format': 'LineFormat'
    }

    attribute_map = {
        'is_visible': 'isVisible',
        'has_title': 'hasTitle',
        'position': 'position',
        'display_unit': 'displayUnit',
        'base_unit_scale': 'baseUnitScale',
        'is_automatic_major_unit': 'isAutomaticMajorUnit',
        'major_unit': 'majorUnit',
        'major_unit_scale': 'majorUnitScale',
        'major_tick_mark': 'majorTickMark',
        'is_automatic_minor_unit': 'isAutomaticMinorUnit',
        'minor_unit': 'minorUnit',
        'minor_unit_scale': 'minorUnitScale',
        'minor_tick_mark': 'minorTickMark',
        'is_automatic_max_value': 'isAutomaticMaxValue',
        'max_value': 'maxValue',
        'is_automatic_min_value': 'isAutomaticMinValue',
        'min_value': 'minValue',
        'is_logarithmic': 'isLogarithmic',
        'log_base': 'logBase',
        'category_axis_type': 'categoryAxisType',
        'axis_between_categories': 'axisBetweenCategories',
        'label_offset': 'labelOffset',
        'is_plot_order_reversed': 'isPlotOrderReversed',
        'is_number_format_linked_to_source': 'isNumberFormatLinkedToSource',
        'number_format': 'numberFormat',
        'cross_type': 'crossType',
        'cross_at': 'crossAt',
        'is_automatic_tick_marks_spacing': 'isAutomaticTickMarksSpacing',
        'tick_marks_spacing': 'tickMarksSpacing',
        'is_automatic_tick_label_spacing': 'isAutomaticTickLabelSpacing',
        'tick_label_spacing': 'tickLabelSpacing',
        'tick_label_position': 'tickLabelPosition',
        'tick_label_rotation_angle': 'tickLabelRotationAngle',
        'fill_format': 'fillFormat',
        'effect_format': 'effectFormat',
        'line_format': 'lineFormat'
    }

    type_determiners = {
    }

    def __init__(self, is_visible=None, has_title=None, position=None, display_unit=None, base_unit_scale=None, is_automatic_major_unit=None, major_unit=None, major_unit_scale=None, major_tick_mark=None, is_automatic_minor_unit=None, minor_unit=None, minor_unit_scale=None, minor_tick_mark=None, is_automatic_max_value=None, max_value=None, is_automatic_min_value=None, min_value=None, is_logarithmic=None, log_base=None, category_axis_type=None, axis_between_categories=None, label_offset=None, is_plot_order_reversed=None, is_number_format_linked_to_source=None, number_format=None, cross_type=None, cross_at=None, is_automatic_tick_marks_spacing=None, tick_marks_spacing=None, is_automatic_tick_label_spacing=None, tick_label_spacing=None, tick_label_position=None, tick_label_rotation_angle=None, fill_format=None, effect_format=None, line_format=None):  # noqa: E501
        """Axis - a model defined in Swagger"""  # noqa: E501

        self._is_visible = None
        self._has_title = None
        self._position = None
        self._display_unit = None
        self._base_unit_scale = None
        self._is_automatic_major_unit = None
        self._major_unit = None
        self._major_unit_scale = None
        self._major_tick_mark = None
        self._is_automatic_minor_unit = None
        self._minor_unit = None
        self._minor_unit_scale = None
        self._minor_tick_mark = None
        self._is_automatic_max_value = None
        self._max_value = None
        self._is_automatic_min_value = None
        self._min_value = None
        self._is_logarithmic = None
        self._log_base = None
        self._category_axis_type = None
        self._axis_between_categories = None
        self._label_offset = None
        self._is_plot_order_reversed = None
        self._is_number_format_linked_to_source = None
        self._number_format = None
        self._cross_type = None
        self._cross_at = None
        self._is_automatic_tick_marks_spacing = None
        self._tick_marks_spacing = None
        self._is_automatic_tick_label_spacing = None
        self._tick_label_spacing = None
        self._tick_label_position = None
        self._tick_label_rotation_angle = None
        self._fill_format = None
        self._effect_format = None
        self._line_format = None

        if is_visible is not None:
            self.is_visible = is_visible
        if has_title is not None:
            self.has_title = has_title
        if position is not None:
            self.position = position
        if display_unit is not None:
            self.display_unit = display_unit
        if base_unit_scale is not None:
            self.base_unit_scale = base_unit_scale
        if is_automatic_major_unit is not None:
            self.is_automatic_major_unit = is_automatic_major_unit
        if major_unit is not None:
            self.major_unit = major_unit
        if major_unit_scale is not None:
            self.major_unit_scale = major_unit_scale
        if major_tick_mark is not None:
            self.major_tick_mark = major_tick_mark
        if is_automatic_minor_unit is not None:
            self.is_automatic_minor_unit = is_automatic_minor_unit
        if minor_unit is not None:
            self.minor_unit = minor_unit
        if minor_unit_scale is not None:
            self.minor_unit_scale = minor_unit_scale
        if minor_tick_mark is not None:
            self.minor_tick_mark = minor_tick_mark
        if is_automatic_max_value is not None:
            self.is_automatic_max_value = is_automatic_max_value
        if max_value is not None:
            self.max_value = max_value
        if is_automatic_min_value is not None:
            self.is_automatic_min_value = is_automatic_min_value
        if min_value is not None:
            self.min_value = min_value
        if is_logarithmic is not None:
            self.is_logarithmic = is_logarithmic
        if log_base is not None:
            self.log_base = log_base
        if category_axis_type is not None:
            self.category_axis_type = category_axis_type
        if axis_between_categories is not None:
            self.axis_between_categories = axis_between_categories
        if label_offset is not None:
            self.label_offset = label_offset
        if is_plot_order_reversed is not None:
            self.is_plot_order_reversed = is_plot_order_reversed
        if is_number_format_linked_to_source is not None:
            self.is_number_format_linked_to_source = is_number_format_linked_to_source
        if number_format is not None:
            self.number_format = number_format
        if cross_type is not None:
            self.cross_type = cross_type
        if cross_at is not None:
            self.cross_at = cross_at
        if is_automatic_tick_marks_spacing is not None:
            self.is_automatic_tick_marks_spacing = is_automatic_tick_marks_spacing
        if tick_marks_spacing is not None:
            self.tick_marks_spacing = tick_marks_spacing
        if is_automatic_tick_label_spacing is not None:
            self.is_automatic_tick_label_spacing = is_automatic_tick_label_spacing
        if tick_label_spacing is not None:
            self.tick_label_spacing = tick_label_spacing
        if tick_label_position is not None:
            self.tick_label_position = tick_label_position
        if tick_label_rotation_angle is not None:
            self.tick_label_rotation_angle = tick_label_rotation_angle
        if fill_format is not None:
            self.fill_format = fill_format
        if effect_format is not None:
            self.effect_format = effect_format
        if line_format is not None:
            self.line_format = line_format

    @property
    def is_visible(self):
        """Gets the is_visible of this Axis.  # noqa: E501

        True if the axis is visible  # noqa: E501

        :return: The is_visible of this Axis.  # noqa: E501
        :rtype: bool
        """
        return self._is_visible

    @is_visible.setter
    def is_visible(self, is_visible):
        """Sets the is_visible of this Axis.

        True if the axis is visible  # noqa: E501

        :param is_visible: The is_visible of this Axis.  # noqa: E501
        :type: bool
        """
        self._is_visible = is_visible

    @property
    def has_title(self):
        """Gets the has_title of this Axis.  # noqa: E501

        True if the axis has a visible title  # noqa: E501

        :return: The has_title of this Axis.  # noqa: E501
        :rtype: bool
        """
        return self._has_title

    @has_title.setter
    def has_title(self, has_title):
        """Sets the has_title of this Axis.

        True if the axis has a visible title  # noqa: E501

        :param has_title: The has_title of this Axis.  # noqa: E501
        :type: bool
        """
        self._has_title = has_title

    @property
    def position(self):
        """Gets the position of this Axis.  # noqa: E501

        Axis position  # noqa: E501

        :return: The position of this Axis.  # noqa: E501
        :rtype: str
        """
        return self._position

    @position.setter
    def position(self, position):
        """Sets the position of this Axis.

        Axis position  # noqa: E501

        :param position: The position of this Axis.  # noqa: E501
        :type: str
        """
        if position is not None:
            allowed_values = ["Bottom", "Left", "Right", "Top"]  # noqa: E501
            if position.isdigit():
                int_position = int(position)
                if int_position < 0 or int_position >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `position` ({0}), must be one of {1}"  # noqa: E501
                        .format(position, allowed_values)
                    )
                self._position = allowed_values[int_position]
                return
            if position not in allowed_values:
                raise ValueError(
                    "Invalid value for `position` ({0}), must be one of {1}"  # noqa: E501
                    .format(position, allowed_values)
                )
        self._position = position

    @property
    def display_unit(self):
        """Gets the display_unit of this Axis.  # noqa: E501

        The scaling value of the display units for the value axis  # noqa: E501

        :return: The display_unit of this Axis.  # noqa: E501
        :rtype: str
        """
        return self._display_unit

    @display_unit.setter
    def display_unit(self, display_unit):
        """Sets the display_unit of this Axis.

        The scaling value of the display units for the value axis  # noqa: E501

        :param display_unit: The display_unit of this Axis.  # noqa: E501
        :type: str
        """
        if display_unit is not None:
            allowed_values = ["None", "Hundreds", "Thousands", "TenThousands", "HundredThousands", "Millions", "TenMillions", "HundredMillions", "Billions", "Trillions", "CustomValue"]  # noqa: E501
            if display_unit.isdigit():
                int_display_unit = int(display_unit)
                if int_display_unit < 0 or int_display_unit >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `display_unit` ({0}), must be one of {1}"  # noqa: E501
                        .format(display_unit, allowed_values)
                    )
                self._display_unit = allowed_values[int_display_unit]
                return
            if display_unit not in allowed_values:
                raise ValueError(
                    "Invalid value for `display_unit` ({0}), must be one of {1}"  # noqa: E501
                    .format(display_unit, allowed_values)
                )
        self._display_unit = display_unit

    @property
    def base_unit_scale(self):
        """Gets the base_unit_scale of this Axis.  # noqa: E501

        The smallest time unit that is represented on the date axis  # noqa: E501

        :return: The base_unit_scale of this Axis.  # noqa: E501
        :rtype: str
        """
        return self._base_unit_scale

    @base_unit_scale.setter
    def base_unit_scale(self, base_unit_scale):
        """Sets the base_unit_scale of this Axis.

        The smallest time unit that is represented on the date axis  # noqa: E501

        :param base_unit_scale: The base_unit_scale of this Axis.  # noqa: E501
        :type: str
        """
        if base_unit_scale is not None:
            allowed_values = ["Days", "Months", "Years"]  # noqa: E501
            if base_unit_scale.isdigit():
                int_base_unit_scale = int(base_unit_scale)
                if int_base_unit_scale < 0 or int_base_unit_scale >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `base_unit_scale` ({0}), must be one of {1}"  # noqa: E501
                        .format(base_unit_scale, allowed_values)
                    )
                self._base_unit_scale = allowed_values[int_base_unit_scale]
                return
            if base_unit_scale not in allowed_values:
                raise ValueError(
                    "Invalid value for `base_unit_scale` ({0}), must be one of {1}"  # noqa: E501
                    .format(base_unit_scale, allowed_values)
                )
        self._base_unit_scale = base_unit_scale

    @property
    def is_automatic_major_unit(self):
        """Gets the is_automatic_major_unit of this Axis.  # noqa: E501

        True the major unit of the axis is automatically assigned  # noqa: E501

        :return: The is_automatic_major_unit of this Axis.  # noqa: E501
        :rtype: bool
        """
        return self._is_automatic_major_unit

    @is_automatic_major_unit.setter
    def is_automatic_major_unit(self, is_automatic_major_unit):
        """Sets the is_automatic_major_unit of this Axis.

        True the major unit of the axis is automatically assigned  # noqa: E501

        :param is_automatic_major_unit: The is_automatic_major_unit of this Axis.  # noqa: E501
        :type: bool
        """
        self._is_automatic_major_unit = is_automatic_major_unit

    @property
    def major_unit(self):
        """Gets the major_unit of this Axis.  # noqa: E501

        The major units for the date or value axis  # noqa: E501

        :return: The major_unit of this Axis.  # noqa: E501
        :rtype: float
        """
        return self._major_unit

    @major_unit.setter
    def major_unit(self, major_unit):
        """Sets the major_unit of this Axis.

        The major units for the date or value axis  # noqa: E501

        :param major_unit: The major_unit of this Axis.  # noqa: E501
        :type: float
        """
        self._major_unit = major_unit

    @property
    def major_unit_scale(self):
        """Gets the major_unit_scale of this Axis.  # noqa: E501

        The major unit scale for the date axis  # noqa: E501

        :return: The major_unit_scale of this Axis.  # noqa: E501
        :rtype: str
        """
        return self._major_unit_scale

    @major_unit_scale.setter
    def major_unit_scale(self, major_unit_scale):
        """Sets the major_unit_scale of this Axis.

        The major unit scale for the date axis  # noqa: E501

        :param major_unit_scale: The major_unit_scale of this Axis.  # noqa: E501
        :type: str
        """
        if major_unit_scale is not None:
            allowed_values = ["Days", "Months", "Years"]  # noqa: E501
            if major_unit_scale.isdigit():
                int_major_unit_scale = int(major_unit_scale)
                if int_major_unit_scale < 0 or int_major_unit_scale >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `major_unit_scale` ({0}), must be one of {1}"  # noqa: E501
                        .format(major_unit_scale, allowed_values)
                    )
                self._major_unit_scale = allowed_values[int_major_unit_scale]
                return
            if major_unit_scale not in allowed_values:
                raise ValueError(
                    "Invalid value for `major_unit_scale` ({0}), must be one of {1}"  # noqa: E501
                    .format(major_unit_scale, allowed_values)
                )
        self._major_unit_scale = major_unit_scale

    @property
    def major_tick_mark(self):
        """Gets the major_tick_mark of this Axis.  # noqa: E501

        The type of major tick mark for the specified axis  # noqa: E501

        :return: The major_tick_mark of this Axis.  # noqa: E501
        :rtype: str
        """
        return self._major_tick_mark

    @major_tick_mark.setter
    def major_tick_mark(self, major_tick_mark):
        """Sets the major_tick_mark of this Axis.

        The type of major tick mark for the specified axis  # noqa: E501

        :param major_tick_mark: The major_tick_mark of this Axis.  # noqa: E501
        :type: str
        """
        if major_tick_mark is not None:
            allowed_values = ["Cross", "Inside", "None", "Outside"]  # noqa: E501
            if major_tick_mark.isdigit():
                int_major_tick_mark = int(major_tick_mark)
                if int_major_tick_mark < 0 or int_major_tick_mark >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `major_tick_mark` ({0}), must be one of {1}"  # noqa: E501
                        .format(major_tick_mark, allowed_values)
                    )
                self._major_tick_mark = allowed_values[int_major_tick_mark]
                return
            if major_tick_mark not in allowed_values:
                raise ValueError(
                    "Invalid value for `major_tick_mark` ({0}), must be one of {1}"  # noqa: E501
                    .format(major_tick_mark, allowed_values)
                )
        self._major_tick_mark = major_tick_mark

    @property
    def is_automatic_minor_unit(self):
        """Gets the is_automatic_minor_unit of this Axis.  # noqa: E501

        True the minor unit of the axis is automatically assigned  # noqa: E501

        :return: The is_automatic_minor_unit of this Axis.  # noqa: E501
        :rtype: bool
        """
        return self._is_automatic_minor_unit

    @is_automatic_minor_unit.setter
    def is_automatic_minor_unit(self, is_automatic_minor_unit):
        """Sets the is_automatic_minor_unit of this Axis.

        True the minor unit of the axis is automatically assigned  # noqa: E501

        :param is_automatic_minor_unit: The is_automatic_minor_unit of this Axis.  # noqa: E501
        :type: bool
        """
        self._is_automatic_minor_unit = is_automatic_minor_unit

    @property
    def minor_unit(self):
        """Gets the minor_unit of this Axis.  # noqa: E501

        The minor units for the date or value axis  # noqa: E501

        :return: The minor_unit of this Axis.  # noqa: E501
        :rtype: float
        """
        return self._minor_unit

    @minor_unit.setter
    def minor_unit(self, minor_unit):
        """Sets the minor_unit of this Axis.

        The minor units for the date or value axis  # noqa: E501

        :param minor_unit: The minor_unit of this Axis.  # noqa: E501
        :type: float
        """
        self._minor_unit = minor_unit

    @property
    def minor_unit_scale(self):
        """Gets the minor_unit_scale of this Axis.  # noqa: E501

        The minor unit scale for the date axis  # noqa: E501

        :return: The minor_unit_scale of this Axis.  # noqa: E501
        :rtype: str
        """
        return self._minor_unit_scale

    @minor_unit_scale.setter
    def minor_unit_scale(self, minor_unit_scale):
        """Sets the minor_unit_scale of this Axis.

        The minor unit scale for the date axis  # noqa: E501

        :param minor_unit_scale: The minor_unit_scale of this Axis.  # noqa: E501
        :type: str
        """
        if minor_unit_scale is not None:
            allowed_values = ["Days", "Months", "Years"]  # noqa: E501
            if minor_unit_scale.isdigit():
                int_minor_unit_scale = int(minor_unit_scale)
                if int_minor_unit_scale < 0 or int_minor_unit_scale >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `minor_unit_scale` ({0}), must be one of {1}"  # noqa: E501
                        .format(minor_unit_scale, allowed_values)
                    )
                self._minor_unit_scale = allowed_values[int_minor_unit_scale]
                return
            if minor_unit_scale not in allowed_values:
                raise ValueError(
                    "Invalid value for `minor_unit_scale` ({0}), must be one of {1}"  # noqa: E501
                    .format(minor_unit_scale, allowed_values)
                )
        self._minor_unit_scale = minor_unit_scale

    @property
    def minor_tick_mark(self):
        """Gets the minor_tick_mark of this Axis.  # noqa: E501

        The type of minor tick mark for the specified axis  # noqa: E501

        :return: The minor_tick_mark of this Axis.  # noqa: E501
        :rtype: str
        """
        return self._minor_tick_mark

    @minor_tick_mark.setter
    def minor_tick_mark(self, minor_tick_mark):
        """Sets the minor_tick_mark of this Axis.

        The type of minor tick mark for the specified axis  # noqa: E501

        :param minor_tick_mark: The minor_tick_mark of this Axis.  # noqa: E501
        :type: str
        """
        if minor_tick_mark is not None:
            allowed_values = ["Cross", "Inside", "None", "Outside"]  # noqa: E501
            if minor_tick_mark.isdigit():
                int_minor_tick_mark = int(minor_tick_mark)
                if int_minor_tick_mark < 0 or int_minor_tick_mark >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `minor_tick_mark` ({0}), must be one of {1}"  # noqa: E501
                        .format(minor_tick_mark, allowed_values)
                    )
                self._minor_tick_mark = allowed_values[int_minor_tick_mark]
                return
            if minor_tick_mark not in allowed_values:
                raise ValueError(
                    "Invalid value for `minor_tick_mark` ({0}), must be one of {1}"  # noqa: E501
                    .format(minor_tick_mark, allowed_values)
                )
        self._minor_tick_mark = minor_tick_mark

    @property
    def is_automatic_max_value(self):
        """Gets the is_automatic_max_value of this Axis.  # noqa: E501

        True if the max value is automatically assigned  # noqa: E501

        :return: The is_automatic_max_value of this Axis.  # noqa: E501
        :rtype: bool
        """
        return self._is_automatic_max_value

    @is_automatic_max_value.setter
    def is_automatic_max_value(self, is_automatic_max_value):
        """Sets the is_automatic_max_value of this Axis.

        True if the max value is automatically assigned  # noqa: E501

        :param is_automatic_max_value: The is_automatic_max_value of this Axis.  # noqa: E501
        :type: bool
        """
        self._is_automatic_max_value = is_automatic_max_value

    @property
    def max_value(self):
        """Gets the max_value of this Axis.  # noqa: E501

        The maximum value on the value axis  # noqa: E501

        :return: The max_value of this Axis.  # noqa: E501
        :rtype: float
        """
        return self._max_value

    @max_value.setter
    def max_value(self, max_value):
        """Sets the max_value of this Axis.

        The maximum value on the value axis  # noqa: E501

        :param max_value: The max_value of this Axis.  # noqa: E501
        :type: float
        """
        self._max_value = max_value

    @property
    def is_automatic_min_value(self):
        """Gets the is_automatic_min_value of this Axis.  # noqa: E501

        True if the min value is automatically assigned  # noqa: E501

        :return: The is_automatic_min_value of this Axis.  # noqa: E501
        :rtype: bool
        """
        return self._is_automatic_min_value

    @is_automatic_min_value.setter
    def is_automatic_min_value(self, is_automatic_min_value):
        """Sets the is_automatic_min_value of this Axis.

        True if the min value is automatically assigned  # noqa: E501

        :param is_automatic_min_value: The is_automatic_min_value of this Axis.  # noqa: E501
        :type: bool
        """
        self._is_automatic_min_value = is_automatic_min_value

    @property
    def min_value(self):
        """Gets the min_value of this Axis.  # noqa: E501

        The minimum value on the value axis  # noqa: E501

        :return: The min_value of this Axis.  # noqa: E501
        :rtype: float
        """
        return self._min_value

    @min_value.setter
    def min_value(self, min_value):
        """Sets the min_value of this Axis.

        The minimum value on the value axis  # noqa: E501

        :param min_value: The min_value of this Axis.  # noqa: E501
        :type: float
        """
        self._min_value = min_value

    @property
    def is_logarithmic(self):
        """Gets the is_logarithmic of this Axis.  # noqa: E501

        True if the value axis scale type is logarithmic  # noqa: E501

        :return: The is_logarithmic of this Axis.  # noqa: E501
        :rtype: bool
        """
        return self._is_logarithmic

    @is_logarithmic.setter
    def is_logarithmic(self, is_logarithmic):
        """Sets the is_logarithmic of this Axis.

        True if the value axis scale type is logarithmic  # noqa: E501

        :param is_logarithmic: The is_logarithmic of this Axis.  # noqa: E501
        :type: bool
        """
        self._is_logarithmic = is_logarithmic

    @property
    def log_base(self):
        """Gets the log_base of this Axis.  # noqa: E501

        The logarithmic base. Default value is 10  # noqa: E501

        :return: The log_base of this Axis.  # noqa: E501
        :rtype: float
        """
        return self._log_base

    @log_base.setter
    def log_base(self, log_base):
        """Sets the log_base of this Axis.

        The logarithmic base. Default value is 10  # noqa: E501

        :param log_base: The log_base of this Axis.  # noqa: E501
        :type: float
        """
        self._log_base = log_base

    @property
    def category_axis_type(self):
        """Gets the category_axis_type of this Axis.  # noqa: E501

        The type of the category axis  # noqa: E501

        :return: The category_axis_type of this Axis.  # noqa: E501
        :rtype: str
        """
        return self._category_axis_type

    @category_axis_type.setter
    def category_axis_type(self, category_axis_type):
        """Sets the category_axis_type of this Axis.

        The type of the category axis  # noqa: E501

        :param category_axis_type: The category_axis_type of this Axis.  # noqa: E501
        :type: str
        """
        if category_axis_type is not None:
            allowed_values = ["Text", "Date"]  # noqa: E501
            if category_axis_type.isdigit():
                int_category_axis_type = int(category_axis_type)
                if int_category_axis_type < 0 or int_category_axis_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `category_axis_type` ({0}), must be one of {1}"  # noqa: E501
                        .format(category_axis_type, allowed_values)
                    )
                self._category_axis_type = allowed_values[int_category_axis_type]
                return
            if category_axis_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `category_axis_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(category_axis_type, allowed_values)
                )
        self._category_axis_type = category_axis_type

    @property
    def axis_between_categories(self):
        """Gets the axis_between_categories of this Axis.  # noqa: E501

        True if the value axis crosses the category axis between categories. This property applies only to category axes, and it doesn't apply to 3-D charts  # noqa: E501

        :return: The axis_between_categories of this Axis.  # noqa: E501
        :rtype: bool
        """
        return self._axis_between_categories

    @axis_between_categories.setter
    def axis_between_categories(self, axis_between_categories):
        """Sets the axis_between_categories of this Axis.

        True if the value axis crosses the category axis between categories. This property applies only to category axes, and it doesn't apply to 3-D charts  # noqa: E501

        :param axis_between_categories: The axis_between_categories of this Axis.  # noqa: E501
        :type: bool
        """
        self._axis_between_categories = axis_between_categories

    @property
    def label_offset(self):
        """Gets the label_offset of this Axis.  # noqa: E501

        The distance of labels from the axis. Applied to category or date axis. Value must be between 0% and 1000%.               # noqa: E501

        :return: The label_offset of this Axis.  # noqa: E501
        :rtype: int
        """
        return self._label_offset

    @label_offset.setter
    def label_offset(self, label_offset):
        """Sets the label_offset of this Axis.

        The distance of labels from the axis. Applied to category or date axis. Value must be between 0% and 1000%.               # noqa: E501

        :param label_offset: The label_offset of this Axis.  # noqa: E501
        :type: int
        """
        self._label_offset = label_offset

    @property
    def is_plot_order_reversed(self):
        """Gets the is_plot_order_reversed of this Axis.  # noqa: E501

        True if MS PowerPoint plots data points from last to first  # noqa: E501

        :return: The is_plot_order_reversed of this Axis.  # noqa: E501
        :rtype: bool
        """
        return self._is_plot_order_reversed

    @is_plot_order_reversed.setter
    def is_plot_order_reversed(self, is_plot_order_reversed):
        """Sets the is_plot_order_reversed of this Axis.

        True if MS PowerPoint plots data points from last to first  # noqa: E501

        :param is_plot_order_reversed: The is_plot_order_reversed of this Axis.  # noqa: E501
        :type: bool
        """
        self._is_plot_order_reversed = is_plot_order_reversed

    @property
    def is_number_format_linked_to_source(self):
        """Gets the is_number_format_linked_to_source of this Axis.  # noqa: E501

        True if the format is linked to source data  # noqa: E501

        :return: The is_number_format_linked_to_source of this Axis.  # noqa: E501
        :rtype: bool
        """
        return self._is_number_format_linked_to_source

    @is_number_format_linked_to_source.setter
    def is_number_format_linked_to_source(self, is_number_format_linked_to_source):
        """Sets the is_number_format_linked_to_source of this Axis.

        True if the format is linked to source data  # noqa: E501

        :param is_number_format_linked_to_source: The is_number_format_linked_to_source of this Axis.  # noqa: E501
        :type: bool
        """
        self._is_number_format_linked_to_source = is_number_format_linked_to_source

    @property
    def number_format(self):
        """Gets the number_format of this Axis.  # noqa: E501

        the format string for the Axis Labels  # noqa: E501

        :return: The number_format of this Axis.  # noqa: E501
        :rtype: str
        """
        return self._number_format

    @number_format.setter
    def number_format(self, number_format):
        """Sets the number_format of this Axis.

        the format string for the Axis Labels  # noqa: E501

        :param number_format: The number_format of this Axis.  # noqa: E501
        :type: str
        """
        self._number_format = number_format

    @property
    def cross_type(self):
        """Gets the cross_type of this Axis.  # noqa: E501

        The CrossType on the specified axis where the other axis crosses  # noqa: E501

        :return: The cross_type of this Axis.  # noqa: E501
        :rtype: str
        """
        return self._cross_type

    @cross_type.setter
    def cross_type(self, cross_type):
        """Sets the cross_type of this Axis.

        The CrossType on the specified axis where the other axis crosses  # noqa: E501

        :param cross_type: The cross_type of this Axis.  # noqa: E501
        :type: str
        """
        if cross_type is not None:
            allowed_values = ["AxisCrossesAtZero", "Maximum", "Custom"]  # noqa: E501
            if cross_type.isdigit():
                int_cross_type = int(cross_type)
                if int_cross_type < 0 or int_cross_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `cross_type` ({0}), must be one of {1}"  # noqa: E501
                        .format(cross_type, allowed_values)
                    )
                self._cross_type = allowed_values[int_cross_type]
                return
            if cross_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `cross_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(cross_type, allowed_values)
                )
        self._cross_type = cross_type

    @property
    def cross_at(self):
        """Gets the cross_at of this Axis.  # noqa: E501

        The point on the axis where the perpendicular axis crosses it  # noqa: E501

        :return: The cross_at of this Axis.  # noqa: E501
        :rtype: float
        """
        return self._cross_at

    @cross_at.setter
    def cross_at(self, cross_at):
        """Sets the cross_at of this Axis.

        The point on the axis where the perpendicular axis crosses it  # noqa: E501

        :param cross_at: The cross_at of this Axis.  # noqa: E501
        :type: float
        """
        self._cross_at = cross_at

    @property
    def is_automatic_tick_marks_spacing(self):
        """Gets the is_automatic_tick_marks_spacing of this Axis.  # noqa: E501

        True for automatic tick marks spacing value  # noqa: E501

        :return: The is_automatic_tick_marks_spacing of this Axis.  # noqa: E501
        :rtype: bool
        """
        return self._is_automatic_tick_marks_spacing

    @is_automatic_tick_marks_spacing.setter
    def is_automatic_tick_marks_spacing(self, is_automatic_tick_marks_spacing):
        """Sets the is_automatic_tick_marks_spacing of this Axis.

        True for automatic tick marks spacing value  # noqa: E501

        :param is_automatic_tick_marks_spacing: The is_automatic_tick_marks_spacing of this Axis.  # noqa: E501
        :type: bool
        """
        self._is_automatic_tick_marks_spacing = is_automatic_tick_marks_spacing

    @property
    def tick_marks_spacing(self):
        """Gets the tick_marks_spacing of this Axis.  # noqa: E501

        Specifies how many tick marks shall be skipped before the next one shall be drawn. Applied to category or series axis.  # noqa: E501

        :return: The tick_marks_spacing of this Axis.  # noqa: E501
        :rtype: int
        """
        return self._tick_marks_spacing

    @tick_marks_spacing.setter
    def tick_marks_spacing(self, tick_marks_spacing):
        """Sets the tick_marks_spacing of this Axis.

        Specifies how many tick marks shall be skipped before the next one shall be drawn. Applied to category or series axis.  # noqa: E501

        :param tick_marks_spacing: The tick_marks_spacing of this Axis.  # noqa: E501
        :type: int
        """
        self._tick_marks_spacing = tick_marks_spacing

    @property
    def is_automatic_tick_label_spacing(self):
        """Gets the is_automatic_tick_label_spacing of this Axis.  # noqa: E501

        True for automatic tick label spacing value  # noqa: E501

        :return: The is_automatic_tick_label_spacing of this Axis.  # noqa: E501
        :rtype: bool
        """
        return self._is_automatic_tick_label_spacing

    @is_automatic_tick_label_spacing.setter
    def is_automatic_tick_label_spacing(self, is_automatic_tick_label_spacing):
        """Sets the is_automatic_tick_label_spacing of this Axis.

        True for automatic tick label spacing value  # noqa: E501

        :param is_automatic_tick_label_spacing: The is_automatic_tick_label_spacing of this Axis.  # noqa: E501
        :type: bool
        """
        self._is_automatic_tick_label_spacing = is_automatic_tick_label_spacing

    @property
    def tick_label_spacing(self):
        """Gets the tick_label_spacing of this Axis.  # noqa: E501

        Specifies how many tick labels to skip between label that is drawn.  # noqa: E501

        :return: The tick_label_spacing of this Axis.  # noqa: E501
        :rtype: int
        """
        return self._tick_label_spacing

    @tick_label_spacing.setter
    def tick_label_spacing(self, tick_label_spacing):
        """Sets the tick_label_spacing of this Axis.

        Specifies how many tick labels to skip between label that is drawn.  # noqa: E501

        :param tick_label_spacing: The tick_label_spacing of this Axis.  # noqa: E501
        :type: int
        """
        self._tick_label_spacing = tick_label_spacing

    @property
    def tick_label_position(self):
        """Gets the tick_label_position of this Axis.  # noqa: E501

        The position of tick-mark labels on the specified axis.  # noqa: E501

        :return: The tick_label_position of this Axis.  # noqa: E501
        :rtype: str
        """
        return self._tick_label_position

    @tick_label_position.setter
    def tick_label_position(self, tick_label_position):
        """Sets the tick_label_position of this Axis.

        The position of tick-mark labels on the specified axis.  # noqa: E501

        :param tick_label_position: The tick_label_position of this Axis.  # noqa: E501
        :type: str
        """
        if tick_label_position is not None:
            allowed_values = ["High", "Low", "NextTo", "None"]  # noqa: E501
            if tick_label_position.isdigit():
                int_tick_label_position = int(tick_label_position)
                if int_tick_label_position < 0 or int_tick_label_position >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `tick_label_position` ({0}), must be one of {1}"  # noqa: E501
                        .format(tick_label_position, allowed_values)
                    )
                self._tick_label_position = allowed_values[int_tick_label_position]
                return
            if tick_label_position not in allowed_values:
                raise ValueError(
                    "Invalid value for `tick_label_position` ({0}), must be one of {1}"  # noqa: E501
                    .format(tick_label_position, allowed_values)
                )
        self._tick_label_position = tick_label_position

    @property
    def tick_label_rotation_angle(self):
        """Gets the tick_label_rotation_angle of this Axis.  # noqa: E501

        Represents the rotation angle of tick labels.  # noqa: E501

        :return: The tick_label_rotation_angle of this Axis.  # noqa: E501
        :rtype: float
        """
        return self._tick_label_rotation_angle

    @tick_label_rotation_angle.setter
    def tick_label_rotation_angle(self, tick_label_rotation_angle):
        """Sets the tick_label_rotation_angle of this Axis.

        Represents the rotation angle of tick labels.  # noqa: E501

        :param tick_label_rotation_angle: The tick_label_rotation_angle of this Axis.  # noqa: E501
        :type: float
        """
        self._tick_label_rotation_angle = tick_label_rotation_angle

    @property
    def fill_format(self):
        """Gets the fill_format of this Axis.  # noqa: E501

        Get or sets the fill format.  # noqa: E501

        :return: The fill_format of this Axis.  # noqa: E501
        :rtype: FillFormat
        """
        return self._fill_format

    @fill_format.setter
    def fill_format(self, fill_format):
        """Sets the fill_format of this Axis.

        Get or sets the fill format.  # noqa: E501

        :param fill_format: The fill_format of this Axis.  # noqa: E501
        :type: FillFormat
        """
        self._fill_format = fill_format

    @property
    def effect_format(self):
        """Gets the effect_format of this Axis.  # noqa: E501

        Get or sets the effect format.  # noqa: E501

        :return: The effect_format of this Axis.  # noqa: E501
        :rtype: EffectFormat
        """
        return self._effect_format

    @effect_format.setter
    def effect_format(self, effect_format):
        """Sets the effect_format of this Axis.

        Get or sets the effect format.  # noqa: E501

        :param effect_format: The effect_format of this Axis.  # noqa: E501
        :type: EffectFormat
        """
        self._effect_format = effect_format

    @property
    def line_format(self):
        """Gets the line_format of this Axis.  # noqa: E501

        Get or sets the line format.  # noqa: E501

        :return: The line_format of this Axis.  # noqa: E501
        :rtype: LineFormat
        """
        return self._line_format

    @line_format.setter
    def line_format(self, line_format):
        """Sets the line_format of this Axis.

        Get or sets the line format.  # noqa: E501

        :param line_format: The line_format of this Axis.  # noqa: E501
        :type: LineFormat
        """
        self._line_format = line_format

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Axis):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six


class SmartArtNode(object):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'nodes': 'list[SmartArtNode]',
        'shapes': 'ResourceUriElement',
        'is_assistant': 'bool',
        'text': 'str',
        'org_chart_layout': 'str'
    }

    attribute_map = {
        'nodes': 'nodes',
        'shapes': 'shapes',
        'is_assistant': 'isAssistant',
        'text': 'text',
        'org_chart_layout': 'orgChartLayout'
    }

    type_determiners = {
    }

    def __init__(self, nodes=None, shapes=None, is_assistant=None, text=None, org_chart_layout=None):  # noqa: E501
        """SmartArtNode - a model defined in Swagger"""  # noqa: E501

        self._nodes = None
        self._shapes = None
        self._is_assistant = None
        self._text = None
        self._org_chart_layout = None

        if nodes is not None:
            self.nodes = nodes
        if shapes is not None:
            self.shapes = shapes
        self.is_assistant = is_assistant
        if text is not None:
            self.text = text
        self.org_chart_layout = org_chart_layout

    @property
    def nodes(self):
        """Gets the nodes of this SmartArtNode.  # noqa: E501

        Node list.  # noqa: E501

        :return: The nodes of this SmartArtNode.  # noqa: E501
        :rtype: list[SmartArtNode]
        """
        return self._nodes

    @nodes.setter
    def nodes(self, nodes):
        """Sets the nodes of this SmartArtNode.

        Node list.  # noqa: E501

        :param nodes: The nodes of this SmartArtNode.  # noqa: E501
        :type: list[SmartArtNode]
        """
        self._nodes = nodes

    @property
    def shapes(self):
        """Gets the shapes of this SmartArtNode.  # noqa: E501

        Gets or sets the link to shapes.  # noqa: E501

        :return: The shapes of this SmartArtNode.  # noqa: E501
        :rtype: ResourceUriElement
        """
        return self._shapes

    @shapes.setter
    def shapes(self, shapes):
        """Sets the shapes of this SmartArtNode.

        Gets or sets the link to shapes.  # noqa: E501

        :param shapes: The shapes of this SmartArtNode.  # noqa: E501
        :type: ResourceUriElement
        """
        self._shapes = shapes

    @property
    def is_assistant(self):
        """Gets the is_assistant of this SmartArtNode.  # noqa: E501

        True for and assistant node.  # noqa: E501

        :return: The is_assistant of this SmartArtNode.  # noqa: E501
        :rtype: bool
        """
        return self._is_assistant

    @is_assistant.setter
    def is_assistant(self, is_assistant):
        """Sets the is_assistant of this SmartArtNode.

        True for and assistant node.  # noqa: E501

        :param is_assistant: The is_assistant of this SmartArtNode.  # noqa: E501
        :type: bool
        """
        self._is_assistant = is_assistant

    @property
    def text(self):
        """Gets the text of this SmartArtNode.  # noqa: E501

        Node text.  # noqa: E501

        :return: The text of this SmartArtNode.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this SmartArtNode.

        Node text.  # noqa: E501

        :param text: The text of this SmartArtNode.  # noqa: E501
        :type: str
        """
        self._text = text

    @property
    def org_chart_layout(self):
        """Gets the org_chart_layout of this SmartArtNode.  # noqa: E501

        Organization chart layout type associated with current node.  # noqa: E501

        :return: The org_chart_layout of this SmartArtNode.  # noqa: E501
        :rtype: str
        """
        return self._org_chart_layout

    @org_chart_layout.setter
    def org_chart_layout(self, org_chart_layout):
        """Sets the org_chart_layout of this SmartArtNode.

        Organization chart layout type associated with current node.  # noqa: E501

        :param org_chart_layout: The org_chart_layout of this SmartArtNode.  # noqa: E501
        :type: str
        """
        if org_chart_layout is not None:
            allowed_values = ["Initial", "Standart", "BothHanging", "LeftHanging", "RightHanging"]  # noqa: E501
            if org_chart_layout.isdigit():
                int_org_chart_layout = int(org_chart_layout)
                if int_org_chart_layout < 0 or int_org_chart_layout >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `org_chart_layout` ({0}), must be one of {1}"  # noqa: E501
                        .format(org_chart_layout, allowed_values)
                    )
                self._org_chart_layout = allowed_values[int_org_chart_layout]
                return
            if org_chart_layout not in allowed_values:
                raise ValueError(
                    "Invalid value for `org_chart_layout` ({0}), must be one of {1}"  # noqa: E501
                    .format(org_chart_layout, allowed_values)
                )
        self._org_chart_layout = org_chart_layout

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SmartArtNode):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

from __future__ import absolute_import


from asposeslidescloud.models.requests.slides_api_requests import CopyFileRequest
from asposeslidescloud.models.requests.slides_api_requests import CopyFolderRequest
from asposeslidescloud.models.requests.slides_api_requests import CreateFolderRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteFileRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteFolderRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteNotesSlideRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteNotesSlideParagraphRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteNotesSlideParagraphsRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteNotesSlidePortionRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteNotesSlidePortionsRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteNotesSlideShapeRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteNotesSlideShapesRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteParagraphRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteParagraphsRequest
from asposeslidescloud.models.requests.slides_api_requests import DeletePortionRequest
from asposeslidescloud.models.requests.slides_api_requests import DeletePortionsRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideAnimationRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideAnimationEffectRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideAnimationInteractiveSequenceRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideAnimationInteractiveSequenceEffectRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideAnimationInteractiveSequencesRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideAnimationMainSequenceRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideByIndexRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideShapeRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideShapesRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlidesCleanSlidesListRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlidesDocumentPropertiesRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlidesDocumentPropertyRequest
from asposeslidescloud.models.requests.slides_api_requests import DeleteSlidesSlideBackgroundRequest
from asposeslidescloud.models.requests.slides_api_requests import DownloadFileRequest
from asposeslidescloud.models.requests.slides_api_requests import GetDiscUsageRequest
from asposeslidescloud.models.requests.slides_api_requests import GetFileVersionsRequest
from asposeslidescloud.models.requests.slides_api_requests import GetFilesListRequest
from asposeslidescloud.models.requests.slides_api_requests import GetLayoutSlideRequest
from asposeslidescloud.models.requests.slides_api_requests import GetLayoutSlidesListRequest
from asposeslidescloud.models.requests.slides_api_requests import GetMasterSlideRequest
from asposeslidescloud.models.requests.slides_api_requests import GetMasterSlidesListRequest
from asposeslidescloud.models.requests.slides_api_requests import GetNotesSlideRequest
from asposeslidescloud.models.requests.slides_api_requests import GetNotesSlideShapeRequest
from asposeslidescloud.models.requests.slides_api_requests import GetNotesSlideShapeParagraphRequest
from asposeslidescloud.models.requests.slides_api_requests import GetNotesSlideShapeParagraphsRequest
from asposeslidescloud.models.requests.slides_api_requests import GetNotesSlideShapePortionRequest
from asposeslidescloud.models.requests.slides_api_requests import GetNotesSlideShapePortionsRequest
from asposeslidescloud.models.requests.slides_api_requests import GetNotesSlideShapesRequest
from asposeslidescloud.models.requests.slides_api_requests import GetNotesSlideWithFormatRequest
from asposeslidescloud.models.requests.slides_api_requests import GetParagraphPortionRequest
from asposeslidescloud.models.requests.slides_api_requests import GetParagraphPortionsRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlideAnimationRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlideShapeRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlideShapeParagraphRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlideShapeParagraphsRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlideShapesRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesDocumentRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesDocumentPropertiesRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesDocumentPropertyRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesImageWithDefaultFormatRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesImageWithFormatRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesImagesRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesPlaceholderRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesPlaceholdersRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesPresentationTextItemsRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesSlideRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesSlideBackgroundRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesSlideCommentsRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesSlideImagesRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesSlideTextItemsRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesSlidesListRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesThemeRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesThemeColorSchemeRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesThemeFontSchemeRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesThemeFormatSchemeRequest
from asposeslidescloud.models.requests.slides_api_requests import GetSlidesViewPropertiesRequest
from asposeslidescloud.models.requests.slides_api_requests import MoveFileRequest
from asposeslidescloud.models.requests.slides_api_requests import MoveFolderRequest
from asposeslidescloud.models.requests.slides_api_requests import ObjectExistsRequest
from asposeslidescloud.models.requests.slides_api_requests import PostAddNewParagraphRequest
from asposeslidescloud.models.requests.slides_api_requests import PostAddNewPortionRequest
from asposeslidescloud.models.requests.slides_api_requests import PostAddNewShapeRequest
from asposeslidescloud.models.requests.slides_api_requests import PostAddNotesSlideRequest
from asposeslidescloud.models.requests.slides_api_requests import PostCopyLayoutSlideFromSourcePresentationRequest
from asposeslidescloud.models.requests.slides_api_requests import PostCopyMasterSlideFromSourcePresentationRequest
from asposeslidescloud.models.requests.slides_api_requests import PostNotesSlideAddNewParagraphRequest
from asposeslidescloud.models.requests.slides_api_requests import PostNotesSlideAddNewPortionRequest
from asposeslidescloud.models.requests.slides_api_requests import PostNotesSlideAddNewShapeRequest
from asposeslidescloud.models.requests.slides_api_requests import PostNotesSlideShapeSaveAsRequest
from asposeslidescloud.models.requests.slides_api_requests import PostPresentationMergeRequest
from asposeslidescloud.models.requests.slides_api_requests import PostShapeSaveAsRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlideAnimationEffectRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlideAnimationInteractiveSequenceRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlideAnimationInteractiveSequenceEffectRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlideSaveAsRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesAddRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesConvertRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesCopyRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesDocumentRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesDocumentFromHtmlRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesDocumentFromSourceRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesDocumentFromTemplateRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesPipelineRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesPresentationReplaceTextRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesReorderRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesReorderManyRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesSaveAsRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesSetDocumentPropertiesRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesSlideReplaceTextRequest
from asposeslidescloud.models.requests.slides_api_requests import PostSlidesSplitRequest
from asposeslidescloud.models.requests.slides_api_requests import PutLayoutSlideRequest
from asposeslidescloud.models.requests.slides_api_requests import PutNotesSlideShapeSaveAsRequest
from asposeslidescloud.models.requests.slides_api_requests import PutPresentationMergeRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSetParagraphPortionPropertiesRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSetParagraphPropertiesRequest
from asposeslidescloud.models.requests.slides_api_requests import PutShapeSaveAsRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlideAnimationRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlideAnimationEffectRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlideAnimationInteractiveSequenceEffectRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlideSaveAsRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlideShapeInfoRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlidesConvertRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlidesDocumentFromHtmlRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlidesSaveAsRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlidesSetDocumentPropertyRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlidesSlideRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlidesSlideBackgroundRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlidesSlideBackgroundColorRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlidesSlideSizeRequest
from asposeslidescloud.models.requests.slides_api_requests import PutSlidesViewPropertiesRequest
from asposeslidescloud.models.requests.slides_api_requests import PutUpdateNotesSlideRequest
from asposeslidescloud.models.requests.slides_api_requests import PutUpdateNotesSlideShapeRequest
from asposeslidescloud.models.requests.slides_api_requests import PutUpdateNotesSlideShapeParagraphRequest
from asposeslidescloud.models.requests.slides_api_requests import PutUpdateNotesSlideShapePortionRequest
from asposeslidescloud.models.requests.slides_api_requests import StorageExistsRequest
from asposeslidescloud.models.requests.slides_api_requests import UploadFileRequest
